@@ -7,7 +7,7 @@ from typing import Union
 from packaging.version import Version
 from redis.client import StrictRedis
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 __file_as_path__ = Path(__file__)
 
 logger = getLogger(__name__)
@@ -75,7 +75,7 @@ class ThrottledQueue(object):
         return self._pop_item_script(client=self._client, keys=(), args=(self._prefix, window, self._limit, int(self._resolution)))
 
     def __len__(self):
-        return self._client.get(self._count_key)
+        return int(self._client.get(self._count_key))
 
     @classmethod
     def register_scripts(cls, redis_client):
